"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Burger = void 0;

var _react = require("react");

const area = 48;
const timing = 'cubic-bezier(0, 0, 0, 1)';
const translate = 4.6325;

const Burger = ({
  color = '#000',
  direction = 'left',
  duration = 0.4,
  hideOutline = true,
  onToggle,
  render,
  rounded = false,
  size = 32,
  toggle,
  toggled
}) => {
  const [toggledInternal, toggleInternal] = (0, _react.useState)(false);
  const width = Math.max(12, Math.min(area, size));
  const room = Math.round((area - width) / 2);
  const barHeightRaw = width / 12;
  const barHeight = Math.round(barHeightRaw);
  const marginRaw = width / 4.5;
  const margin = Math.round(marginRaw);
  const height = barHeight * 3 + margin * 2;
  const topOffset = Math.round((area - height) / 2);
  const deviation = barHeightRaw - barHeight + (marginRaw - margin);
  const move = (width / translate - deviation / (4 / 3)).toFixed(2);
  const time = Math.max(0, duration);
  const burgerStyles = {
    cursor: 'pointer',
    height: `${area}px`,
    position: 'relative',
    transition: `${time}s ${timing}`,
    userSelect: 'none',
    width: `${area}px`
  };
  const barStyles = {
    background: color,
    height: `${barHeight}px`,
    left: `${room}px`,
    position: 'absolute',
    width: `${width}px`
  };

  if (hideOutline) {
    burgerStyles['outline'] = 'none';
  }

  if (rounded) {
    barStyles['borderRadius'] = '9em';
  }

  const hasExternalSetter = toggle !== undefined;
  const hasExternalState = toggled !== undefined;
  const isExternal = hasExternalSetter && hasExternalState;
  const isInternal = !hasExternalSetter && !hasExternalState;
  const isToggled = hasExternalState ? toggled : toggledInternal;

  const handler = () => {
    if (onToggle && (isExternal || isInternal)) {
      onToggle(!isToggled);
    }

    if (isExternal) {
      toggle(!isToggled);
    } else if (isInternal) {
      toggleInternal(!isToggled);
    }
  };

  return render({
    barHeight,
    barStyles,
    burgerStyles,
    handler,
    isLeft: direction === 'left',
    isToggled,
    margin,
    move,
    time,
    timing,
    topOffset
  });
};

exports.Burger = Burger;